@@ -14,7 +14,7 @@
 #' agm(1, sqrt(2))
 #' 2*pi^(3/2)*sqrt(2) / gamma(1/4)^2
 agm <- function(x, y){
-  if(x + y == 0){
+  if(x + y == 0 || x == 0 || y == 0){
     return(0)
   }
   pi/4 * (x + y) / elliptic_F(pi/2, ((x-y)/(x+y))^2)
